# punchbowl

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.14029123.svg)](https://doi.org/10.5281/zenodo.14029123)

`punchbowl` is the science calibration code for [the PUNCH mission](https://punch.space.swri.edu/).

### [Start by checking the documentation.](https://punchbowl.readthedocs.io/en/latest/)

> [!CAUTION]
> This package is still being heavily edited as calibration algorithms are improved.
> Stability is not promised until v1.

## Accessing the data

Data are available via the Solar Data Analysis Center.
See [the PUNCH website](https://punch.space.swri.edu/punch_science_getdata.php) for details.

## Installing `punchbowl`

Install with `pip install punchbowl` to get the released version.

To get the latest unreleased version: clone the repo and install it locally.

## Running `punchbowl`

[The documentation](https://punchbowl.readthedocs.io/en/latest/index.html) provides details on how to run the various components.
It also provides a short explanation of each underlying algorithm.
Please reach out with a discussion for more help.

## Testing

You need Docker or Podman Desktop.

1. Install Podman Desktop using your preferred method
2. Pull the mariadb image with podman pull docker.io/library/mariadb
3. Run tests with pytest


## Getting help

Please open an issue or discussion on this repo.

## Contributing

We appreciate all contributions.
If you have a problem with the code or would like to see a new feature, please open an issue.
Or you can submit a pull request.

Thanks to all the contributors to punchbowl!

<a href="https://github.com/punch-mission/punchbowl/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=punch-mission/punchbowl" />
</a>
